@@ -14,8 +14,6 @@ use strict;
 # and which buttons belong to some named group.
 #
 
-use Log::Agent;
-
 #
 # ->new
 #
@@ -124,7 +122,7 @@ sub _validate_radios
             # invalid operation.  We're resettting the attribute directly.
             #
 
-            logwarn
+            warn
               "found %d checked %ss for '%s', keeping first (tag \"%s\")",
               $checked, $first->gui_type, $gname, ($first->value || "");
 
@@ -136,7 +134,7 @@ sub _validate_radios
         elsif ($checked == 0)
         {
             my $first = $this->{$gname}->[ 0 ];
-            logwarn "no checked %ss for '%s', checking first (tag \"%s\")",
+            warn "no checked %ss for '%s', checking first (tag \"%s\")",
               $first->gui_type, $gname, ($first->value || "");
             $first->{is_checked} = 1;    # Direct access
         }
@@ -202,24 +200,13 @@ name is not a valid group name, the list will be empty.
 
 =back
 
-=head1 WEBSITE
-
-You can find information about CGI::Test and other related modules at:
-
-   http://cgi-test.sourceforge.net
-
-=head1 PUBLIC CVS SERVER
-
-CGI::Test now has a publicly accessible CVS server provided by
-SourceForge (www.sourceforge.net).  You can access it by going to:
-
-    http://sourceforge.net/cvs/?group_id=89570
-
 =head1 AUTHORS
 
-The original author is Raphael Manfredi F<E<lt>Raphael_Manfredi@pobox.comE<gt>>. 
+The original author is Raphael Manfredi.
 
-Send bug reports, hints, tips, suggestions to Steven Hilton at <mshiltonj@mshiltonj.com>
+Steven Hilton was long time maintainer of this module.
+
+Current maintainer is Alexander Tokarev F<E<lt>tokarev@cpan.orgE<gt>>.
 
 =head1 SEE ALSO
 
