@@ -10,15 +10,14 @@ use strict;
 #  as specified in the README file that comes with the distribution.
 #
 
+use Carp;
+
 #
 # This class models a FORM box, either a radio button or a checkbox.
 #
 
-use CGI::Test::Form::Widget;
 use base qw(CGI::Test::Form::Widget);
 
-use Log::Agent;
-
 ############################################################
 #
 # %attr
@@ -212,7 +211,7 @@ sub is_box
 ############################################################
 sub is_radio
 {
-    logconfess "deferred";
+    confess "deferred";
 }
 ############################################################
 sub is_standalone
@@ -274,12 +273,12 @@ sub _mark_by_tag
 
     if (@boxes == 0)
     {
-        logcarp "no %s within the group '%s' bears the tag \"$tag\"",
+        carp "no %s within the group '%s' bears the tag \"$tag\"",
           $this->gui_type(), $this->name();
     }
     else
     {
-        logcarp "found %d %ss within the group '%s' bearing the tag \"$tag\"",
+        carp "found %d %ss within the group '%s' bearing the tag \"$tag\"",
           scalar(@boxes), $this->gui_type(), $this->name()
           if @boxes > 1;
 
@@ -345,7 +344,7 @@ This may be called on any box, and it will locate the box whose value
 attribute is I<tag> within the C<group_list>, and then check it.
 
 If the specified I<tag> is not found, the caller will get a warning
-via C<logcarp>.
+via C<carp>.
 
 =item C<uncheck>
 
@@ -361,7 +360,7 @@ It is not possible to do this on a radio button, as explained in C<uncheck>
 above.
 
 If the specified I<tag> is not found, the caller will get a warning
-via C<logcarp>.
+via C<carp>.
 
 =back
 
@@ -404,24 +403,13 @@ of calling this feature.
 
 =back
 
-=head1 WEBSITE
-
-You can find information about CGI::Test and other related modules at:
-
-   http://cgi-test.sourceforge.net
-
-=head1 PUBLIC CVS SERVER
-
-CGI::Test now has a publicly accessible CVS server provided by
-SourceForge (www.sourceforge.net).  You can access it by going to:
-
-    http://sourceforge.net/cvs/?group_id=89570
-
 =head1 AUTHORS
 
-The original author is Raphael Manfredi F<E<lt>Raphael_Manfredi@pobox.comE<gt>>. 
+The original author is Raphael Manfredi.
 
-Send bug reports, hints, tips, suggestions to Steven Hilton at <mshiltonj@mshiltonj.com>
+Steven Hilton was long time maintainer of this module.
+
+Current maintainer is Alexander Tokarev F<E<lt>tokarev@cpan.orgE<gt>>.
 
 =head1 SEE ALSO
 
