@@ -15,11 +15,8 @@ use strict;
 # This class models a FORM checkbox button.
 #
 
-use CGI::Test::Form::Widget::Box;
 use base qw(CGI::Test::Form::Widget::Box);
 
-use Log::Agent;
-
 #
 # Attribute access
 #
@@ -49,11 +46,9 @@ CGI::Test::Form::Widget::Box::Check - A checkbox widget
  # Inherits from CGI::Test::Form::Widget::Box
  # $form is a CGI::Test::Form
 
- use Log::Agent;    # logdie below
-
  my ($agree, $ads) = $form->checkbox_by_name(qw(i_agree ads));
 
- logdie "expected a standalone checkbox" unless $agree->is_standalone;
+ die "expected a standalone checkbox" unless $agree->is_standalone;
  $agree->check;
  $ads->uncheck_tagged("spam OK");
 
@@ -65,24 +60,13 @@ at will by users.
 The interface is the same as the one described
 in L<CGI::Test::Form::Widget::Box>.
 
-=head1 WEBSITE
-
-You can find information about CGI::Test and other related modules at:
-
-   http://cgi-test.sourceforge.net
-
-=head1 PUBLIC CVS SERVER
-
-CGI::Test now has a publicly accessible CVS server provided by
-SourceForge (www.sourceforge.net).  You can access it by going to:
-
-    http://sourceforge.net/cvs/?group_id=89570
-
 =head1 AUTHORS
 
-The original author is Raphael Manfredi F<E<lt>Raphael_Manfredi@pobox.comE<gt>>. 
+The original author is Raphael Manfredi.
 
-Send bug reports, hints, tips, suggestions to Steven Hilton at <mshiltonj@mshiltonj.com>
+Steven Hilton was long time maintainer of this module.
+
+Current maintainer is Alexander Tokarev F<E<lt>tokarev@cpan.orgE<gt>>.
 
 =head1 SEE ALSO
 
