@@ -11,15 +11,14 @@ use strict;
 #  as specified in the README file that comes with the distribution.
 #
 
+use Carp;
+
 #
 # This class models a FORM radio button.
 #
 
-use CGI::Test::Form::Widget::Box;
 use base qw(CGI::Test::Form::Widget::Box);
 
-use Log::Agent;
-
 #
 # ->set_is_checked		-- redefined
 #
@@ -53,12 +52,12 @@ sub set_is_checked
 
 sub uncheck
 {
-    logcarp "ignoring uncheck on radio button";
+    carp "ignoring uncheck on radio button";
 }
 
 sub uncheck_tagged
 {
-    logcarp "ignoring uncheck_tagged on radio button";
+    carp "ignoring uncheck_tagged on radio button";
 }
 
 #
@@ -104,37 +103,25 @@ will by users.  All other radio buttons of the same group are automatically
 unchecked.
 
 If no radio button is checked initially, C<CGI::Test> arbitrarily chooses
-the first one listed and warns you via C<logwarn>.
+the first one listed and warns you via C<warn>.
 
 The interface is the same as the one described
 in L<CGI::Test::Form::Widget::Box>.
 
 Any attempt to C<uncheck> a radio button will be ignored, and a warning
-emitted via C<logcarp>, to help you identify the caller.
-
-=head1 WEBSITE
-
-You can find information about CGI::Test and other related modules at:
-
-   http://cgi-test.sourceforge.net
-
-=head1 PUBLIC CVS SERVER
-
-CGI::Test now has a publicly accessible CVS server provided by
-SourceForge (www.sourceforge.net).  You can access it by going to:
-
-    http://sourceforge.net/cvs/?group_id=89570
+emitted via C<carp>, to help you identify the caller.
 
 =head1 AUTHORS
 
-The original author is Raphael Manfredi F<E<lt>Raphael_Manfredi@pobox.comE<gt>>. 
+The original author is Raphael Manfredi.
 
-Send bug reports, hints, tips, suggestions to Steven Hilton at <mshiltonj@mshiltonj.com>
+Steven Hilton was long time maintainer of this module.
+
+Current maintainer is Alexander Tokarev F<E<lt>tokarev@cpan.orgE<gt>>.
 
 =head1 SEE ALSO
 
-CGI::Test::Form::Widget::Box(3), CGI::Test::Form::Widget::Box::Check(3),
-Log::Agent(3).
+CGI::Test::Form::Widget::Box(3), CGI::Test::Form::Widget::Box::Check(3).
 
 =cut
 
