@@ -10,15 +10,15 @@ use strict;
 #  You may redistribute only under the terms of the Artistic License,
 #  as specified in the README file that comes with the distribution.
 #
+
+use Carp;
+
 #
 # This class models a FORM reset button.
 #
 
-require CGI::Test::Form::Widget::Button;
 use base qw(CGI::Test::Form::Widget::Button);
 
-use Log::Agent;
-
 #
 # Attribute access
 #
@@ -84,24 +84,13 @@ client-side, and no request is made to the HTTP server.
 The interface is the same as the one described in
 L<CGI::Test::Form::Widget::Button>.
 
-=head1 WEBSITE
-
-You can find information about CGI::Test and other related modules at:
-
-   http://cgi-test.sourceforge.net
-
-=head1 PUBLIC CVS SERVER
-
-CGI::Test now has a publicly accessible CVS server provided by
-SourceForge (www.sourceforge.net).  You can access it by going to:
-
-    http://sourceforge.net/cvs/?group_id=89570
-
 =head1 AUTHORS
 
-The original author is Raphael Manfredi F<E<lt>Raphael_Manfredi@pobox.comE<gt>>. 
+The original author is Raphael Manfredi.
 
-Send bug reports, hints, tips, suggestions to Steven Hilton at <mshiltonj@mshiltonj.com>
+Steven Hilton was long time maintainer of this module.
+
+Current maintainer is Alexander Tokarev F<E<lt>tokarev@cpan.orgE<gt>>.
 
 =head1 SEE ALSO
 
