@@ -11,16 +11,15 @@ use strict;
 #  as specified in the README file that comes with the distribution.
 #
 
+use Carp;
+
 #
 # This class models a FORM input field.
 # It factorizes the interface of our heirs: Text_Area and Text_Field
 #
 
-use CGI::Test::Form::Widget;
 use base qw(CGI::Test::Form::Widget);
 
-use Log::Agent;
-
 #
 # ->_is_successful		-- defined
 #
@@ -211,24 +210,13 @@ Returns I<true> for a password field (text field with input masked by GUI).
 
 =back
 
-=head1 WEBSITE
-
-You can find information about CGI::Test and other related modules at:
-
-   http://cgi-test.sourceforge.net
-
-=head1 PUBLIC CVS SERVER
-
-CGI::Test now has a publicly accessible CVS server provided by
-SourceForge (www.sourceforge.net).  You can access it by going to:
-
-    http://sourceforge.net/cvs/?group_id=89570
-
 =head1 AUTHORS
 
-The original author is Raphael Manfredi F<E<lt>Raphael_Manfredi@pobox.comE<gt>>. 
+The original author is Raphael Manfredi.
 
-Send bug reports, hints, tips, suggestions to Steven Hilton at <mshiltonj@mshiltonj.com>
+Steven Hilton was long time maintainer of this module.
+
+Current maintainer is Alexander Tokarev F<E<lt>tokarev@cpan.orgE<gt>>.
 
 =head1 SEE ALSO
 
