@@ -10,15 +10,15 @@ use strict;
 #  You may redistribute only under the terms of the Artistic License,
 #  as specified in the README file that comes with the distribution.
 #
+
+use Carp;
+
 #
 # This class models a FORM text field.
 #
 
-use CGI::Test::Form::Widget::Input;
 use base qw(CGI::Test::Form::Widget::Input);
 
-use Log::Agent;
-
 #
 # %attr
 #
@@ -96,7 +96,7 @@ sub set_value
 
     if (defined $maxlen && length($value) > $maxlen)
     {
-        logcarp "truncating text to %d byte%s for %s '%s'", $maxlen,
+        carp "truncating text to %d byte%s for %s '%s'", $maxlen,
           $maxlen == 1 ? "" : "s", $this->gui_type, $this->name;
         substr($value, $maxlen) = '';
     }
@@ -141,24 +141,13 @@ the field can be much larger than that, however.
 
 =back
 
-=head1 WEBSITE
-
-You can find information about CGI::Test and other related modules at:
-
-   http://cgi-test.sourceforge.net
-
-=head1 PUBLIC CVS SERVER
-
-CGI::Test now has a publicly accessible CVS server provided by
-SourceForge (www.sourceforge.net).  You can access it by going to:
-
-    http://sourceforge.net/cvs/?group_id=89570
-
 =head1 AUTHORS
 
-The original author is Raphael Manfredi F<E<lt>Raphael_Manfredi@pobox.comE<gt>>. 
+The original author is Raphael Manfredi.
 
-Send bug reports, hints, tips, suggestions to Steven Hilton at <mshiltonj@mshiltonj.com>
+Steven Hilton was long time maintainer of this module.
+
+Current maintainer is Alexander Tokarev F<E<lt>tokarev@cpan.orgE<gt>>.
 
 =head1 SEE ALSO
 
