@@ -11,15 +11,14 @@ use strict;
 #  as specified in the README file that comes with the distribution.
 #
 
+use Carp;
+
 #
 # This class models a FORM popup menu.
 #
 
-use CGI::Test::Form::Widget::Menu;
 use base qw(CGI::Test::Form::Widget::Menu);
 
-use Log::Agent;
-
 #
 # %attr
 #
@@ -58,7 +57,7 @@ sub set_selected
 
     unless ($state)
     {
-        logcarp "cannot unselect value \"%s\" from popup $this", $value;
+        carp "cannot unselect value \"%s\" from popup $this", $value;
         return;
     }
 
@@ -104,31 +103,20 @@ and for which there is at least one item selected, i.e. where exactly one
 item is chosen.
 
 If no item was explicitely selected, C<CGI::Test> arbitrarily chooses the
-first item in the popup (if not empty) and warns you via C<logwarn>.
+first item in the popup (if not empty) and warns you via C<warn>.
 
 =head1 INTERFACE
 
 The interface is the same as the one described in
 L<CGI::Test::Form::Widget::Menu>.
 
-=head1 WEBSITE
-
-You can find information about CGI::Test and other related modules at:
-
-   http://cgi-test.sourceforge.net
-
-=head1 PUBLIC CVS SERVER
-
-CGI::Test now has a publicly accessible CVS server provided by
-SourceForge (www.sourceforge.net).  You can access it by going to:
-
-    http://sourceforge.net/cvs/?group_id=89570
-
 =head1 AUTHORS
 
-The original author is Raphael Manfredi F<E<lt>Raphael_Manfredi@pobox.comE<gt>>. 
+The original author is Raphael Manfredi.
 
-Send bug reports, hints, tips, suggestions to Steven Hilton at <mshiltonj@mshiltonj.com>
+Steven Hilton was long time maintainer of this module.
+
+Current maintainer is Alexander Tokarev F<E<lt>tokarev@cpan.orgE<gt>>.
 
 =head1 SEE ALSO
 
